aboutsummaryrefslogtreecommitdiffstats
path: root/specgen.sh
diff options
context:
space:
mode:
Diffstat (limited to 'specgen.sh')
-rwxr-xr-xspecgen.sh48
1 files changed, 29 insertions, 19 deletions
diff --git a/specgen.sh b/specgen.sh
index 234d7fee..46223799 100755
--- a/specgen.sh
+++ b/specgen.sh
@@ -1,15 +1,23 @@
cat <<EOF
-Description: Remote mail fetch daemon for POP2, POP3, APOP, IMAP
-Name: fetchmail
-Version: ${1}
-Release: 1
-Vendor: Eric Conspiracy Secret Labs
-Source: locke.ccil.org:/pub/esr/fetchmail/fetchmail-${1}.tar.gz
-URL: http://www.ccil.org/~esr/fetchmail
-Group: Applications/Mail
-Copyright: GPL
-Icon: fetchmail.gif
-Requires: smtpdaemon
+Name: fetchmail
+Version: ${1}
+Release: 1
+Vendor: Eric Conspiracy Secret Labs
+Source: locke.ccil.org:/pub/esr/fetchmail/fetchmail-${1}.tar.gz
+URL: http://earthspace.net/~esr/fetchmail
+Group: Applications/Mail
+Copyright: GPL
+Icon: fetchmail.gif
+Requires: smtpdaemon
+BuildRoot: /tmp/fetchmail-%{version}-root
+
+%description
+fetchmail is a free, full-featured, robust, and well-documented remote
+mail retrieval and forwarding utility intended to be used over
+on-demand TCP/IP links (such as SLIP or PPP connections). It
+retrieves mail from remote mail servers and forwards it to your local
+(client) machine's delivery system, so it can then be be read by
+normal mail user agents such as mutt, elm, pine, or mailx.
%prep
%setup
@@ -19,14 +27,16 @@ CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=/usr
make
%install
-make install
-
-%files
-%doc README NEWS NOTES fetchmail-FAQ.html FAQ COPYING INSTALL sample.rcfile
+rm -rf $RPM_BUILD_ROOT
+mkdir -p $RPM_BUILD_ROOT/usr/{bin,man/man1}
+make prefix=$RPM_BUILD_ROOT/usr install
-%ifarch i386
-%endif
+%clean
+rm -rf $RPM_BUILD_ROOT
-/usr/bin/fetchmail
-/usr/man/man1/fetchmail.1
+%files
+%attr(-,root,root) %doc README NEWS NOTES fetchmail-FAQ.html FAQ COPYING INSTALL
+sample.rcfile
+%attr(-,root,root) /usr/bin/fetchmail
+%attr(-,root,root) /usr/man/man1/fetchmail.1
EOF